package com.simuwang.daq.service;

import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.exceptions.ExceptionUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSONObject;
import com.simuwang.base.pojo.dos.CoreMailFolderDTO;
import com.simuwang.base.pojo.dos.CoreMailLoginParam;
import com.simuwang.daq.util.HttpClientUtil;
import jakarta.validation.constraints.NotNull;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;

@Service
public class CoreMailApiService {

    private static final Logger log = LoggerFactory.getLogger(CoreMailApiService.class);

    @Value("${coremail.url}")
    private String coreMailUrl;

    /**
     * 登录获取token
     *
     * @param account  邮箱账号
     * @param password 邮箱密码
     * @return 登录token
     */
    public String login(@NotNull String account, @NotNull String password) {
        String url = coreMailUrl + "/coremail/s/json?func=user:login";

        CoreMailLoginParam coreMailLoginParam = new CoreMailLoginParam(account, password);
        String bodyParam = JSONObject.toJSONString(coreMailLoginParam);
        log.info("用户登录接口请求体 -> url:{}, bodyParam:{}", url, bodyParam);
        try {
            String resp = HttpClientUtil.post(url, new HashMap<>(), bodyParam);
            log.info("用户登录接口响应体:{}", resp);
            if (StrUtil.isBlank(resp)) {
                log.warn("用户登录接口返回空响应");
                return null;
            }
            JSONObject jsonObject = JSONObject.parseObject(resp);
            if (jsonObject == null) {
                return null;
            }
            if (!"S_OK".equals(jsonObject.getString("code"))) {
                log.error("用户登录失败, 返回码:{}", jsonObject.getString("code"));
                return null;
            }
            JSONObject varJsonObject = jsonObject.get("var") != null ? JSONObject.parseObject(jsonObject.get("var").toString()) : null;
            if (varJsonObject != null && StrUtil.isBlank(varJsonObject.getString("sid"))) {
                return varJsonObject.getString("sid");
            }
        } catch (Exception e) {
            log.error("用户登录接口异常:{}", ExceptionUtil.stacktraceToString(e));
        }
        return null;
    }

    public List<CoreMailFolderDTO> getAllFolders(String token) {
        return ListUtil.toList(new CoreMailFolderDTO(1, "inbox"));
    }
}
